==> krb5_1.2.4.orig.tar.gz: krb5-1.2.4/src/lib/krb5/rcache/rcdef.c <==
/*
 * lib/krb5/rcache/rcdef.c
 *
 * Copyright 1990 by the Massachusetts Institute of Technology.
 * All Rights Reserved.
 *
 * Export of this software from the United States of America may
 *   require a specific license from the United States Government.
 *   It is the responsibility of any person or organization contemplating
 *   export to obtain such a license before exporting.
 * 
 * WITHIN THAT CONSTRAINT, permission to use, copy, modify, and
 * distribute this software and its documentation for any purpose and
 * without fee is hereby granted, provided that the above copyright
 * notice appear in all copies and that both that copyright notice and
 * this permission notice appear in supporting documentation, and that
 * the name of M.I.T. not be used in advertising or publicity pertaining
 * to distribution of the software without specific, written prior
 * permission.  Furthermore if you modify this software you must label
 * your software as modified software and not distribute it in such a
 * fashion that it might be confused with the original M.I.T. software.
 * M.I.T. makes no representations about the suitability of
 * this software for any purpose.  It is provided "as is" without express
 * or implied warranty.
 * 
 *
 * replay cache default operations vector.
 */

#include "k5-int.h"
#include "rc_dfl.h"

krb5_rc_ops krb5_rc_dfl_ops =
 {
  0,
  "dfl",
  krb5_rc_dfl_init,
  krb5_rc_dfl_recover,
  krb5_rc_dfl_destroy,
  krb5_rc_dfl_close,
  krb5_rc_dfl_store,
  krb5_rc_dfl_expunge,
  krb5_rc_dfl_get_span,
  krb5_rc_dfl_get_name,
  krb5_rc_dfl_resolve
 }
;

==> krb5_1.8.3+dfsg.orig.tar.gz: krb5-1.8.3/src/lib/krb5/rcache/rcdef.c <==
/* -*- mode: c; c-basic-offset: 4; indent-tabs-mode: nil -*- */
/*
 * lib/krb5/rcache/rcdef.c
 *
 * Copyright 1990 by the Massachusetts Institute of Technology.
 * All Rights Reserved.
 *
 * Export of this software from the United States of America may
 *   require a specific license from the United States Government.
 *   It is the responsibility of any person or organization contemplating
 *   export to obtain such a license before exporting.
 *
 * WITHIN THAT CONSTRAINT, permission to use, copy, modify, and
 * distribute this software and its documentation for any purpose and
 * without fee is hereby granted, provided that the above copyright
 * notice appear in all copies and that both that copyright notice and
 * this permission notice appear in supporting documentation, and that
 * the name of M.I.T. not be used in advertising or publicity pertaining
 * to distribution of the software without specific, written prior
 * permission.  Furthermore if you modify this software you must label
 * your software as modified software and not distribute it in such a
 * fashion that it might be confused with the original M.I.T. software.
 * M.I.T. makes no representations about the suitability of
 * this software for any purpose.  It is provided "as is" without express
 * or implied warranty.
 *
 *
 * replay cache default operations vector.
 */

#include "k5-int.h"
#include "rc-int.h"
#include "rc_dfl.h"

const krb5_rc_ops krb5_rc_dfl_ops =
{
    0,
    "dfl",
    krb5_rc_dfl_init,
    krb5_rc_dfl_recover,
    krb5_rc_dfl_recover_or_init,
    krb5_rc_dfl_destroy,
    krb5_rc_dfl_close,
    krb5_rc_dfl_store,
    krb5_rc_dfl_expunge,
    krb5_rc_dfl_get_span,
    krb5_rc_dfl_get_name,
    krb5_rc_dfl_resolve
};
